function sQ4 = SigmaQ4PSN(E,ni,x1,y1,x2,y2,x3,y3,x4,y4,u)
%Wyznacza skadowe stanu naprezenia dla pojedynczego elementu czworokatnego Q4
%na podstawie parametrow materialowych, wspolrzednych wezlow i obliczonych
%wczesniej przemieszczen wezlow w Plaskim Stanie Naprezenia
%wynik 3x4 (3 skadowe w 4 punktach Gaussa)

%1. Macierz sprezystosci - plaski stan naprezenia
D = Dpsn(E, ni);

%WSPOLRZEDNE PUNKTOW GAUSSA
ksi(1) = -sqrt(1.0 ./ 3.0);
eta(1) = sqrt(1.0 ./ 3.0);

ksi(2) = sqrt(1.0 ./ 3.0);
eta(2) = sqrt(1.0 ./ 3.0);

ksi(3) = sqrt(1.0 ./ 3.0);
eta(3) = -sqrt(1.0 ./ 3.0);

ksi(4) = -sqrt(1.0 ./ 3.0);
eta(4) = -sqrt(1.0 ./ 3.0);

%OBLICZENIA W PUNKTACH GAUSSA
sQ4=zeros(3,4);
for i = 1:4
    
    %2. Macierz Jacobiego
    Jacobi = Q4J(x1, y1, x2, y2, x3, y3, x4, y4, ksi(i), eta(i));

    %3. Jacobian - wyznacznik z macierzy Jakobiego
    detJacobi = det(Jacobi);

    %4. Odwrocona macierz Jacobiego
    invJacobi = inv(Jacobi);

    %5. Pochodne funkcji ksztaltu po zmiennych lokalnych
    dNdL = Q4derivNL(ksi(i), eta(i));

    %6. Pochodne funkcji ksztaltu po zmiennych globalnych
    dNdx = Q4derivNx(invJacobi, dNdL);

    %7. Ukladanie macierzy B
    B = Q4makeB(dNdx);

    %8. Oblicza skladowe naprezenia: iloczyn D*B*u
    sQ4(:,i) = D * B * u;
end
